//{{NO_DEPENDENCIES}}
// Microsoft Visual C++ generated include file.
// Used by fred.rc
//
#define IDC_SAVE_DEFAULT_PREFS          3
#define ID_DELETE_VARIABLE              3
#define ID_DELETE_VARIABLE2             4
#define IDC_NO_SHIELDS                  5
#define IDD_ABOUTBOX                    100
#define ID_MY_STATUS_BAR                101
#define IDD_VOICE_MANAGER               102
#define IDD_BRIEFING_PERSONAS           103
#define IDR_MAINFRAME                   128
#define IDR_MAINMENU                    128
#define IDR_FREDTYPE                    129
#define IDR_CAMPAIGN_VIEW               130
#define IDR_CAMPAIGN_DLG                131
#define IDR_TOOLBAR1                    150
#define IDD_SHIP_EDITBAR                154
#define IDD_SHIP_CLASS_EDITOR           161
#define IDD_AI_CLASS_EDITOR             162
#define IDD_MESSAGE_EDITOR              163
#define IDD_SHIP_GOALSS                 165
#define IDD_SHIP_GOALS2                 166
#define IDD_SHIP_GOALS                  166
#define IDD_SHIP_GOALS_EDITOR           166
#define IDD_MODEL_EDITOR                168
#define IDD_ART_EDITOR                  170
#define IDD_SOUND_EDITOR                171
#define IDD_MISSION_NOTES               172
#define IDD_MUSIC_EDITOR                173
#define IDD_TERRAIN_EDITOR              174
#define IDD_PREFERENCES                 175
#define IDD_SHIP_EDITOR                 176
#define IDD_WEAPON_EDITOR               177
#define IDD_SHIP_MARKINGS               178
#define IDD_DIALOG1                     179
#define IDD_MISSION_GOALS               179
#define IDD_DIALOG2                     180
#define IDD_HELP_INPUT_INTERFACE        180
#define IDD_DIALOG3                     181
#define IDD_SHIP_SELECT                 181
#define IDD_GRID                        182
#define IDR_MENU_SHIP_POPUP             183
#define IDR_MENU_EDIT_POPUP             184
#define IDR_MENU1                       185
#define IDR_MENU_MISSION_GOALS_TREE     188
#define IDR_MENU_EDIT_SEXP_TREE         188
#define IDR_SHIP_EDIT_MENU              191
#define IDD_WING_EDITOR                 192
#define IDR_WING_EDIT_MENU              196
#define IDD_OPERATOR_ARGUMENT_TYPES     198
#define IDD_PLAYER_EDITOR               199
#define IDD_LOADOUT_EDITOR              199
#define IDD_ORIENT_EDITOR               200
#define IDR_PLAYER_EDIT_MENU            202
#define IDD_EVENT_EDITOR                203
#define IDD_EDITORS_MESSAGES            205
#define IDD_STARFIELD                   206
#define IDD_BG_BITMAP                   207
#define IDD_REINFORCEMENT_EDITOR        208
#define IDD_REINFORCEMENT_SELECT        209
#define IDD_WAYPOINT_PATH_EDITOR        210
#define IDR_WAYPOINT_PATH_EDIT_MENU     211
#define IDD_WING_CREATE                 212
#define IDD_INITIAL_STATUS              214
#define IDD_ASTEROID_EDITOR             215
#define IDD_CAMPAIGN                    216
#define IDD_TEXT_VIEW                   218
#define IDC_CURSOR1                     219
#define IDC_CURSOR2                     220
#define IDD_BRIEFING_EDITOR             221
#define IDD_IGNORE_ORDERS               222
#define IDD_DEBRIEFING_EDITOR           223
#define IDB_OPERATOR                    226
#define IDB_DATA                        227
#define IDB_ROOT                        228
#define IDD_ADJUST_GRID                 230
#define IDD_SHIELD_SYS                  231
#define IDR_ASTEROID_FIELD_MENU         232
#define IDR_CPGN_VIEW_OFF               233
#define IDR_CPGN_VIEW_ON                234
#define IDD_INITIAL_SHIPS               238
#define IDB_CHAINED                     239
#define IDD_CMD_BRIEF                   242
#define IDD_SHIP_FLAGS                  243
#define IDB_PLAY                        244
#define IDI_PLAY                        245
#define IDB_ROOT_DIRECTIVE              247
#define IDB_CHAINED_DIRECTIVE           248
#define IDB_GREEN_DOT                   249
#define IDB_BLACK_DOT                   250
#define IDB_VARIABLE                    253
#define IDD_ADD_VARIABLE                255
#define IDD_MODIFY_VARIABLE             256
#define IDD_SPECIAL_DAMAGE              258
#define IDD_DUMP_STATS                  261
#define IDD_SHIP_TEXTURES               263
#define IDD_SPECIAL_HITPOINTS           264
#define IDD_SET_GLOBAL_SHIP_FLAGS       266
#define IDD_CUSTOM_WING_NAMES           267
#define IDD_RESTRICT_PATHS              270
#define IDD_BACKGROUND_CHOOSER          272
#define IDB_DATA_05                     277
#define IDB_DATA_10                     286
#define IDD_ALT_SHIP_CLASS              292
#define IDB_DATA_15                     296
#define IDB_DATA_00                     297
#define IDB_DATA_20                     300
#define IDB_DATA_25                     301
#define IDB_DATA_30                     302
#define IDB_DATA_35                     303
#define IDB_DATA_40                     304
#define IDB_DATA_45                     305
#define IDB_DATA_50                     306
#define IDB_DATA_55                     307
#define IDB_DATA_60                     308
#define IDB_DATA_65                     309
#define IDB_DATA_70                     310
#define IDB_DATA_75                     311
#define IDB_DATA_80                     312
#define IDB_DATA_85                     313
#define IDB_DATA_90                     314
#define IDB_DATA_95                     315
#define IDD_FICTION_VIEWER              318
#define IDD_SOUND_ENVIRONMENT           319
#define IDC_SHIP_CLASS                  1003
#define IDC_SHIP_WING                   1004
#define IDC_SOUND_CLIP_NAME             1007
#define IDC_WEAPON_ARTCLIP_OR_OBJECT    1008
#define IDC_ALLY_ARRIVAL_TRACK          1009
#define IDC_SCLASS_DEBRIS_MODEL         1009
#define IDC_WEAPON_FLASH_ARTCLIP        1010
#define IDC_SCLASS_AI_CLASS             1011
#define IDC_SHIP_APPEAR_SKILL           1011
#define IDC_WEAPON_IMPACT_ARTCLIP       1011
#define IDC_DISPLAY                     1012
#define IDC_FAILED_MISSION_TRACK        1012
#define IDC_GOAL1_IMPORTANCE            1012
#define IDC_WEAPON_TRAILS_ARTCLIP       1012
#define IDC_SUCCESSFUL_MISSION_TRACK    1013
#define IDC_SCLASS_TURRET_WEAPON1       1013
#define IDC_WING_SHIPS                  1013
#define IDC_GOAL2_IMPORTANCE            1013
#define IDC_SPIN_POSITIONX              1014
#define IDC_GOAL3_IMPORTANCE            1014
#define IDC_DEBRIEFING_TRACK            1015
#define IDC_POS_Y                       1015
#define IDC_WING_WAVES                  1015
#define IDC_WEAPON_SPEED                1015
#define IDC_SPIN_POSITIONY              1016
#define IDC_SPIN_POSITIONX11            1016
#define IDC_POS_Z                       1017
#define IDC_WING_WAVE_THRESHOLD         1017
#define IDC_WEAPON_DAMAGE               1017
#define IDC_SPIN_POSITIONZ              1018
#define IDC_SPIN_POSITIONX12            1018
#define IDC_SCLASS_MAX_SPEED            1019
#define IDC_SHIP_WEAPON1                1019
#define IDC_WEAPON_ENERGY_AMMO_USAGE    1019
#define IDC_SPIN_POSITIONX2             1020
#define IDC_SHIP_WEAPON2                1020
#define IDC_SPIN_POSITIONX22            1020
#define IDC_WING_SPECIAL_SHIP           1021
#define IDC_MODEL_NAME                  1021
#define IDC_WEAPON_LIGHT_CAST           1021
#define IDC_AI_DETERMINATION            1022
#define IDC_SHIP_WEAPON_SPECIAL         1022
#define IDC_SPIN_POSITIONX23            1022
#define IDC_SPIN_POSITIONX7             1023
#define IDC_SCLASS_EXPLOSION1           1023
#define IDC_WEAPON_FIRE_DELAY           1023
#define IDC_AI_MORALLE                  1024
#define IDC_SCLASS_EXPLOSION2           1024
#define IDC_SHIP_TURRET_WEAPON1         1024
#define IDC_SPIN_POSITIONX24            1024
#define IDC_CHECK1                      1025
#define IDC_SPIN_POSITIONX8             1025
#define IDC_WING_CRUISE_FORMATION       1025
#define IDC_WEAPON_LIFESPAN             1025
#define IDC_LIGHT                       1025
#define IDC_ENABLE_ASTEROIDS            1025
#define IDC_CRITICAL                    1025
#define IDC_STARTING_WING               1025
#define IDC_HILIGHT                     1025
#define IDC_GOAL_INVALID                1025
#define IDC_DESTROY_CHECK               1025
#define IDC_SCLASS_SHIELDS              1026
#define IDC_WING_ATTACK_FORMATION       1026
#define IDC_SPIN_POSITIONX25            1026
#define IDC_SPIN_POSITIONX3             1027
#define IDC_OBJECT_POSITIONX14          1027
#define IDC_WEAPON_FIRING_SOUND         1027
#define IDC_AI_AGGRESSION               1028
#define IDC_SCLASS_AFTERBURNER          1028
#define IDC_WEAPON_FLYING_SOUND         1028
#define IDC_SCLASS_MAX_PITCH            1029
#define IDC_SHIP_SCORE                  1029
#define IDC_WEAPON_IMPACT_SOUND         1029
#define IDC_SPIN_POSITIONX4             1030
#define IDC_SHIP_CARGO2                 1030
#define IDC_WEAPON_FIRING_POSITION      1030
#define IDC_SCLASS_MAX_BANK             1031
#define IDC_SPIN_POSITIONX5             1032
#define IDC_MARKINGS                    1032
#define IDC_ART_CLIP_SIZE               1033
#define IDC_GOAL1_ACTION                1033
#define IDC_RADIO1                      1034
#define IDC_SPIN_POSITIONX9             1034
#define IDC_ART_CLIP_FRAMES             1034
#define IDC_WAYPOINT_EDITOR             1034
#define IDC_SHIP_CARGO1                 1034
#define IDC_GOAL2_ACTION                1034
#define IDC_GALATEA                     1034
#define IDC_TYPE_STRING                 1034
#define IDC_DOGFIGHT                    1034
#define IDC_PASSIVE_SHIP                1034
#define IDC_FIELD_SHIP                  1034
#define IDC_SEP_UNDERSCORES             1034
#define IDC_EXPORT_EVERYTHING           1034
#define IDC_RADIO2                      1035
#define IDC_AI_ACCURACY                 1035
#define IDC_SHIP_EDITOR                 1035
#define IDC_GOAL3_ACTION                1035
#define IDC_BASTION                     1035
#define IDC_TYPE_NUMBER                 1035
#define IDC_PASSIVE_ASTEROID            1035
#define IDC_FIELD_ASTEROID              1035
#define IDC_SEP_NOTHING                 1035
#define IDC_EXPORT_COMMAND_BRIEFINGS    1035
#define IDC_RADIO3                      1036
#define IDC_SCLASS_MAX_ROLL             1036
#define IDC_GOAL_EDITOR                 1036
#define IDC_WING_NAME                   1036
#define IDC_SOUND_CLIP_DESCRIPTION      1036
#define IDC_COOP                        1036
#define IDC_ACTIVE_FIELD                1036
#define IDC_SEP_DASHES                  1036
#define IDC_EXPORT_BRIEFINGS            1036
#define IDC_SPIN_POSITIONX6             1037
#define IDC_RADIO4                      1037
#define IDC_WAYPOINTS                   1037
#define IDC_TEAMVTEAM                   1037
#define IDC_PASSIVE_FIELD               1037
#define IDC_EXPORT_DEBRIEFINGS          1037
#define IDC_SPIN_POSITIONX10            1038
#define IDC_OBJECT_POSITIONY2           1038
#define IDC_SCLASS_SCORE                1038
#define IDC_SHIP_RESET_TO_DEFAULTS      1038
#define IDC_RADIO7                      1038
#define IDC_SHIP_RESET                  1038
#define IDC_ARRIVAL_CUE1                1038
#define IDC_EXPORT_MESSAGES             1038
#define IDC_SPIN_POSITIONY2             1039
#define IDC_SOUNDS                      1039
#define IDC_RADIO5                      1039
#define IDC_FURBALL                     1039
#define IDC_OBJECT_POSITIONZ2           1040
#define IDC_GOALS                       1040
#define IDC_GOAL1_OBJECT1               1040
#define IDC_RADIO6                      1040
#define IDC_RADIO8                      1040
#define IDC_DEPARTURE_CUE1              1040
#define IDC_PRIORITY2                   1040
#define IDC_SPIN_POSITIONZ2             1041
#define IDC_SCLASS_POWER_PLANT          1041
#define IDC_GOAL1_ACTIVE                1041
#define IDC_RADIO9                      1041
#define IDC_ARRIVAL_CUE2a               1041
#define IDC_SPIN2                       1041
#define IDC_GOALS2                      1041
#define IDC_OBJECT_POSITIONX15          1042
#define IDC_SCLASS_ENGINES              1042
#define IDC_GOAL1_OBJECT2               1042
#define IDC_RADIO10                     1042
#define IDC_ARRIVAL_CUE1a               1042
#define IDC_SHIP_TURRET_WEAPON2         1043
#define IDC_GOAL1_OBJECT3               1043
#define IDC_SPIN_POSITIONX13            1044
#define IDC_SCLASS_WARPDRIVE            1044
#define IDC_GOAL1_OBJECT4               1044
#define IDC_RADIO11                     1044
#define IDC_DEPARTURE_CUE2a             1044
#define IDC_OBJECT_POSITIONY3           1045
#define IDC_GOAL2_OBJECT1               1045
#define IDC_SOUND_CLIP_FILENAME         1045
#define IDC_RADIO12                     1045
#define IDC_DEPARTURE_CUE1a             1045
#define IDC_SPIN_POSITIONY3             1046
#define IDC_GOAL2_ACTIVE                1046
#define IDC_OBJECT_POSITIONZ3           1047
#define IDC_GOAL2_OBJECT2               1047
#define IDC_PRIORITY3                   1047
#define IDC_SPIN_POSITIONZ3             1048
#define IDC_SCLASS_ARMOR                1048
#define IDC_GOAL2_OBJECT3               1048
#define IDC_SPIN3                       1048
#define IDC_OBJECT_POSITIONX16          1049
#define IDC_GOAL2_OBJECT4               1049
#define IDC_DEPARTURE_DELAY_SPIN        1049
#define IDC_SPIN_POSITIONX14            1050
#define IDC_GOAL3_OBJECT1               1050
#define IDC_AI_CLASS_NEW                1050
#define IDC_OBJECT_POSITIONY4           1051
#define IDC_GOAL3_ACTIVE                1051
#define IDC_AI_CLASS_DELETE             1051
#define IDC_SPIN_POSITIONY4             1052
#define IDC_SHIP_DEPARTURE_TRACK        1052
#define IDC_GOAL3_OBJECT2               1052
#define IDC_SOUND_CLIP_PLAY             1052
#define IDC_OBJECT_POSITIONZ4           1053
#define IDC_GOAL3_OBJECT3               1053
#define IDC_SOUND_CLIP_STOP             1053
#define IDC_PRIORITY4                   1053
#define IDC_SPIN_POSITIONZ4             1054
#define IDC_GOAL3_OBJECT4               1054
#define IDC_SPIN4                       1054
#define IDC_OBJECT_POSITIONX17          1055
#define IDC_SPIN_POSITIONX15            1056
#define IDC_OBJECT_POSITIONY5           1057
#define IDC_SHIP_ALT_ARRIVAL            1057
#define IDC_SPIN_POSITIONY5             1058
#define IDC_OBJECT_POSITIONZ5           1059
#define IDC_PRIORITY5                   1059
#define IDC_SPIN_POSITIONZ5             1060
#define IDC_SPIN5                       1060
#define IDC_OBJECT_POSITIONX18          1061
#define IDC_WING_ADD_SHIP               1061
#define IDC_CREATE_SHIP                 1061
#define IDC_SPIN_POSITIONX16            1062
#define IDC_BUTTON1                     1062
#define IDC_FLAGS                       1062
#define IDC_PLAY                        1062
#define IDC_SQUAD_LOGO_BUTTON           1062
#define IDC_ADD_SUN                     1062
#define IDC_DUMP_TO_FILE                1062
#define IDC_LOOP_BRIEF_BROWSE           1062
#define IDC_BUG                         1062
#define IDC_AUTOGENERATE                1062
#define IDC_GENERATE_FILE_NAMES         1062
#define IDC_OBJECT_POSITIONY6           1063
#define IDC_SOUND_CLIP_VOLUME           1063
#define IDC_ADD_SBITMAP                 1063
#define IDC_GENERATE_SCRIPT             1063
#define IDC_SPIN_POSITIONY6             1064
#define IDC_OBJECT_POSITIONZ6           1065
#define IDC_MISSION_NOTES               1065
#define IDC_PRIORITY6                   1065
#define IDC_SPIN_POSITIONZ6             1066
#define IDC_MISSION_TITLE               1066
#define IDC_SPIN6                       1066
#define IDC_OBJECT_POSITIONX19          1067
#define IDC_SPIN_POSITIONX17            1068
#define IDC_OBJECT_POSITIONY7           1069
#define IDC_SPIN_POSITIONY7             1070
#define IDC_OBJECT_POSITIONZ7           1071
#define ID_SHOW_FIGHTERS                1071
#define IDC_PRIORITY7                   1071
#define IDC_SPIN_POSITIONZ7             1072
#define ID_SHOW_CAPITALSHIPS            1072
#define IDC_SPIN7                       1072
#define IDC_OBJECT_POSITIONX20          1073
#define ID_SHOW_PLANETS                 1073
#define IDC_SPIN_POSITIONX18            1074
#define ID_SHOW_MISCOBJECTS             1074
#define IDC_OBJECT_POSITIONY8           1075
#define ID_SHOW_WAYPOINTS               1075
#define IDC_SPIN_POSITIONY8             1076
#define ID_SHOW_GRID                    1076
#define IDC_OBJECT_POSITIONZ8           1077
#define ID_SHOW_ELEVATIONS              1077
#define IDC_PRIORITY8                   1077
#define IDC_SPIN_POSITIONZ8             1078
#define IDC_MESSAGE                     1078
#define IDC_SPIN8                       1078
#define IDC_ABBREV_MESSAGE              1078
#define IDC_OBJECT_POSITIONX21          1079
#define IDC_MESSAGE_DESCRIPTION         1079
#define IDC_SPIN_POSITIONX19            1080
#define IDC_MESSAGE_AUDIO_CLIP          1080
#define IDC_OBJECT_POSITIONY9           1081
#define IDC_MESSAGE_VIDEO_CLIP          1081
#define IDC_SPIN_POSITIONY9             1082
#define IDC_SOUND_EDITOR                1082
#define IDC_OBJECT_POSITIONZ9           1083
#define IDC_ART_EDITOR                  1083
#define IDC_PRIORITY9                   1083
#define IDC_SPIN_POSITIONZ9             1084
#define IDC_MESSAGE_TEXT_COLOR          1084
#define IDC_SPIN9                       1084
#define IDC_OBJECT_POSITIONX22          1085
#define IDC_MESSAGE_NEW                 1085
#define IDC_SPIN_POSITIONX20            1086
#define IDC_MESSAGE_DELETE              1086
#define IDC_OBJECT_POSITIONY10          1087
#define IDC_AI_CLASS_NAME               1087
#define IDC_SPIN_POSITIONY10            1088
#define IDC_AI_CRUISING_SPEED           1088
#define IDC_OBJECT_POSITIONZ10          1089
#define IDC_AI_ATTACK_SPEED             1089
#define IDC_PRIORITY1                   1089
#define IDC_SPIN_POSITIONZ10            1090
#define IDC_AI_EVASION_STYLE            1090
#define IDC_SPIN1                       1090
#define IDC_OBJECT_POSITIONX23          1091
#define IDC_ART_CLIP_NAME               1091
#define IDC_SPIN_POSITIONX21            1092
#define IDC_ART_CLIP_FILENAME           1092
#define IDC_OBJECT_POSITIONY11          1093
#define IDC_ART_CLIP_DESCRIPTION        1093
#define IDC_SPIN_POSITIONY11            1094
#define IDC_ART_CLIP_LIGHT_CAST         1094
#define IDC_OBJECT_POSITIONZ11          1095
#define IDC_ART_CLIP_SELF_ILLUM         1095
#define IDC_PRIORITY10                  1095
#define IDC_SPIN_POSITIONZ11            1096
#define IDC_ART_CLIP_ANIM_RATE          1096
#define IDC_SPIN10                      1096
#define IDC_ART_CLIP_LOOP               1097
#define IDC_ART_CLIP_PINGPONG           1098
#define IDC_ART_CLIP_PREV               1099
#define IDC_CHECK3                      1100
#define IDC_ART_CLIP_NEXT               1100
#define IDC_UPDATE_ARRIVAL              1100
#define IDC_CHECK4                      1101
#define IDC_ART_CLIP_NEW                1101
#define IDC_IGNORE_COUNT                1101
#define IDC_CHECK5                      1102
#define IDC_ART_CLIP_DEL                1102
#define IDC_CHECK6                      1103
#define IDC_ART_CLIP_DISPLAYWINDOW      1103
#define IDC_CHECK7                      1104
#define IDC_SPIN_POSITIONX27            1104
#define IDC_BRIEFING_TRACK              1104
#define IDC_CHECK8                      1105
#define IDC_MAIN_TRACK                  1105
#define IDC_GOAL1_REPEATS               1105
#define IDC_CHECK9                      1106
#define IDC_SPIN_POSITIONX28            1106
#define IDC_ENEMY_ARRIVAL_TRACK         1106
#define IDC_CHECK10                     1107
#define IDC_ENEMY_DEATH_TRACK           1107
#define IDC_GOAL1_SPEED                 1107
#define IDC_CHECK11                     1108
#define IDC_ALLY_DEATH_TRACK            1108
#define IDC_SPIN_POSITIONX29            1108
#define IDC_MODEL_FILENAME              1109
#define IDC_GOAL2_REPEATS               1109
#define IDC_SPIN_POSITIONX30            1110
#define IDC_MODEL_WINDOW                1110
#define IDC_MODEL_NEW                   1111
#define IDC_GOAL2_SPEED                 1111
#define IDC_MODEL_DELETE                1112
#define IDC_SPIN_POSITIONX31            1112
#define IDC_SCLASS_NAME                 1113
#define IDC_GOAL3_REPEATS               1113
#define IDC_SCLASS_IFF                  1114
#define IDC_SPIN_POSITIONX32            1114
#define IDC_SCLASS_3D_OBJECT            1115
#define IDC_GOAL3_SPEED                 1115
#define IDC_SCLASS_CLOAK                1116
#define IDC_SCLASS_NEW                  1117
#define IDC_SCLASS_DELETE               1118
#define IDC_MODELS                      1119
#define IDC_SCLASS_WEAPON2              1120
#define IDC_SCLASS_WEAPON1              1121
#define IDC_SCLASS_WEAPON_SPECIAL       1122
#define IDC_SCLASS_TURRET_WEAPON2       1123
#define IDC_SCLASS_MANUFACTURER         1124
#define IDC_SCLASS_WINDOW               1125
#define IDC_SHIP_NAME                   1126
#define IDC_POS_X                       1127
#define IDC_SHIP_IFF                    1128
#define IDC_SHIP_AI_CLASS               1129
#define IDC_SHIP_STATUS                 1130
#define IDC_SHIP_ARRIVAL                1131
#define IDC_SHIP_DEPARTURE              1132
#define IDC_SHIP_ALT_DEPARTURE          1133
#define IDC_SHIP_PREV                   1134
#define IDC_SHIP_NEXT                   1135
#define IDC_SHIP_ARRIVAL_TRACK          1136
#define IDC_SOUND_CLIP_LOOP             1137
#define IDC_SOUND_CLIP_NEW              1138
#define IDC_SOUND_CLIP_DELETE           1139
#define IDC_SOUND_CLIP_WINDOW           1140
#define IDC_SHIP_PREVIOUS               1141
#define IDC_WEAPON_NAME                 1143
#define IDC_WEAPON_DESCRIPTION          1144
#define IDC_WEAPON_MASS                 1145
#define IDC_WEAPON_NEW                  1146
#define IDC_WEAPON_DELETE               1147
#define IDC_CLOSE                       1148
#define IDC_WING_DELETE_SHIP            1149
#define IDC_DELETE_SHIP                 1149
#define IDC_ADD_TO_WING                 1150
#define IDC_REMOVE_FROM_WING            1151
#define IDC_WING_FORM_WING              1152
#define IDC_WING_INCREASE_WING          1153
#define IDC_WING_NEXT_WING              1154
#define IDC_WING_NEW_WING               1155
#define IDC_WING_PREV_WING              1156
#define IDC_WING_TEXT_WING              1157
#define IDC_GRID_XZ_PLANE               1158
#define IDC_GRID_XY_PLANE               1159
#define IDC_GRID_YZ_PLANE               1160
#define IDC_GRID_SIZE                   1162
#define IDC_SPIN_GRID_SIZE              1164
#define IDC_STATIC_GRID_SIZE            1165
#define IDC_PREF_STARFIELD              1167
#define IDC_GOALS_TREE                  1169
#define IDC_DISPLAY_GOAL_TYPES_DROP     1173
#define IDC_GOAL_DESC                   1176
#define IDC_GOAL_RATING                 1180
#define IDC_GOAL_TYPE_DROP              1181
#define IDC_BUTTON_NEW_GOAL             1183
#define IDC_BUTTON_VERIFY               1184
#define IDC_SHIP_TEAM                   1185
#define IDC_DESIGNER                    1186
#define IDC_DESIGNER_NAME               1186
#define IDC_MODIFIED                    1187
#define IDC_COMBO1                      1188
#define IDC_DOCKER_POINT                1188
#define IDC_MISSION_TYPE                1188
#define IDC_ICON_IMAGE                  1188
#define IDC_ARRIVAL_TARGET              1188
#define IDC_SINGLE_START                1188
#define IDC_PERSONA_NAME                1188
#define IDC_MODIFY_VARIABLE_NAME        1188
#define IDC_SUN1                        1188
#define IDC_SHIP_DEBRIS1                1188
#define IDC_OLD_TEXTURE                 1188
#define IDC_ASCT1_CLASS_COMBO1          1188
#define IDC_SHIP_VARIABLES_COMBO        1188
#define IDC_SUFFIX                      1188
#define IDC_SOUND_ENVIRONMENT           1188
#define IDC_CREATED                     1189
#define IDC_DEPARTURE_TARGET            1189
#define IDC_SBITMAP                     1189
#define IDC_ASCT1_VARIABLES_COMBO1      1189
#define IDC_WEAPON_VARIABLES_COMBO      1189
#define IDC_ASCT1_CLASS_COMBO2          1190
#define IDC_BACKGROUND_NUM              1190
#define IDC_WING_DISPLAY_FILTER         1191
#define IDC_ASCT1_VARIABLES_COMBO2      1191
#define IDC_BACKGROUND_SWAP_NUM         1191
#define IDC_SHIP_DEBRIS2                1192
#define IDC_ASCT1_CLASS_COMBO3          1192
#define IDC_SHIP_LIST                   1193
#define IDC_SHIP_DEBRIS3                1193
#define IDC_ASCT1_VARIABLES_COMBO3      1193
#define IDC_AI_CLASS                    1194
#define IDC_ASCT2_CLASS_COMBO1          1194
#define IDC_SHIP_VARIABLES_LIST         1194
#define IDC_ASCT2_VARIABLES_COMBO1      1195
#define IDC_NEW_WING                    1197
#define IDC_DELETE_WING                 1197
#define IDC_BUTTON2                     1198
#define IDC_DISBAND_WING                1198
#define ID_BOOLEAN                      1198
#define IDC_DELETE                      1198
#define IDC_WEAPONS                     1198
#define IDC_MOVE_DOWN                   1198
#define IDC_DEL_SUN                     1198
#define IDC_COPY_VIEW                   1198
#define IDC_LOADING_SCREEN_BUTTON640    1198
#define IDC_FORUMS                      1198
#define IDC_ALT_CLASS_ADD               1198
#define IDC_DELETE_STAGE                1199
#define IDC_DELETE_MSG                  1199
#define IDC_TOGGLE_LOOP                 1199
#define IDC_DEL_SBITMAP                 1199
#define IDC_ALT_CLASS_DELETE            1199
#define IDC_DELETE2                     1200
#define IDC_TREE2                       1200
#define IDC_TREE3                       1201
#define IDC_OBJECT_LIST                 1202
#define IDC_OBJECT1                     1202
#define IDC_SENDER                      1202
#define IDC_TYPE                        1202
#define IDC_FILENAME                    1202
#define IDC_DEFAULT                     1202
#define IDC_GUN1                        1202
#define IDC_COMBO2                      1203
#define IDC_BEHAVIOR1                   1203
#define IDC_WAVE_FILENAME               1203
#define IDC_GUN2                        1203
#define IDC_DOCKEE_POINT                1203
#define IDC_TEAM                        1203
#define IDC_EVENT_MUSIC                 1203
#define IDC_NEBPATTERN                  1203
#define IDC_SHIP_PERSONA                1203
#define IDC_SET_FROM_SHIP_CLASS         1203
#define IDC_NEBCOLOR                    1204
#define IDC_SUBSTITUTE_EVENT_MUSIC      1205
#define IDC_AI_PROFILE                  1207
#define IDC_LIST3                       1208
#define IDC_FILELIST                    1208
#define IDC_YES_MESSAGE_LIST            1208
#define IDC_ALT_CLASS_LIST              1208
#define IDC_COMMAND_SENDER              1209
#define IDC_COMMAND_PERSONA             1210
#define IDC_FILTER_WAYPOINTS            1211
#define IDC_FILTER_STARTS               1212
#define IDC_FILTER_SHIPS                1213
#define IDC_FILTER_SHIPS_IFF_0          1214
#define IDC_FILTER_SHIPS_IFF_1          1215
#define IDC_FILTER_SHIPS_IFF_2          1216
#define IDC_FILTER_SHIPS_IFF_3          1217
#define IDC_ALL                         1218
#define IDC_CLEAR                       1219
#define IDC_INVERT                      1220
#define IDC_SPIN_WAVES                  1221
#define IDC_FILTER_SHIPS_IFF_4          1221
#define IDC_SPIN_WAVE_THRESHOLD         1222
#define IDC_FILTER_SHIPS_IFF_5          1222
#define IDC_ARRIVAL_LOCATION            1223
#define IDC_FILTER_SHIPS_IFF_6          1223
#define IDC_ARRIVAL_CUE2                1224
#define IDC_FILTER_SHIPS_IFF_7          1224
#define IDC_DEPARTURE_LOCATION          1225
#define IDC_FILTER_SHIPS_IFF_8          1225
#define IDC_DEPARTURE_CUE2              1226
#define IDC_FILTER_SHIPS_IFF_9          1226
#define IDC_ARRIVAL_TREE                1227
#define IDC_DEPARTURE_TREE              1228
#define ID_NUMBERS                      1229
#define ID_SHIPS                        1230
#define ID_WINGS                        1231
#define IDC_POSITION_X                  1235
#define IDC_POSITION_Y                  1236
#define IDC_POSITION_Z                  1237
#define IDC_LOCATION_X                  1238
#define IDC_LOCATION_Y                  1239
#define IDC_LOCATION_Z                  1240
#define IDC_POINT_TO_CHECKBOX           1241
#define IDC_POINT_TO_OBJECT             1242
#define IDC_POINT_TO_LOCATION           1243
#define IDC_COMBO3                      1244
#define IDC_OBJECT2                     1244
#define IDC_AVI_FILENAME                1244
#define IDC_GUN3                        1244
#define IDC_SHIP_TYPE                   1244
#define IDC_NEB2_TEXTURE                1244
#define IDC_SHIP_ALT                    1244
#define IDC_SET_FROM_VARIABLES          1244
#define IDC_TEAMSELECT                  1244
#define IDC_COMBO4                      1245
#define IDC_BEHAVIOR2                   1245
#define IDC_PRIORITY                    1245
#define IDC_BRIEFING_MUSIC              1245
#define IDC_EVENT_TEAM                  1245
#define IDC_NEB2_LIGHTNING              1245
#define IDC_COMBO5                      1246
#define IDC_OBJECT3                     1246
#define IDC_MISSILE1                    1246
#define IDC_MESSAGE_TEAM                1246
#define IDC_SHIP_CALLSIGN               1246
#define IDC_COMBO6                      1247
#define IDC_BEHAVIOR3                   1247
#define IDC_MISSILE2                    1247
#define IDC_COMBO7                      1248
#define IDC_OBJECT4                     1248
#define IDC_MISSILE3                    1248
#define IDC_COMBO8                      1249
#define IDC_BEHAVIOR4                   1249
#define IDC_MISSILE4                    1249
#define IDC_COMBO9                      1250
#define IDC_OBJECT5                     1250
#define IDC_COMBO10                     1251
#define IDC_BEHAVIOR5                   1251
#define IDC_COMBO11                     1252
#define IDC_OBJECT6                     1252
#define IDC_COMBO12                     1253
#define IDC_BEHAVIOR6                   1253
#define IDC_COMBO13                     1254
#define IDC_OBJECT7                     1254
#define IDC_COMBO14                     1255
#define IDC_BEHAVIOR7                   1255
#define IDC_COMBO15                     1256
#define IDC_OBJECT8                     1256
#define IDC_COMBO16                     1257
#define IDC_BEHAVIOR8                   1257
#define IDC_COMBO17                     1258
#define IDC_OBJECT9                     1258
#define IDC_COMBO18                     1259
#define IDC_BEHAVIOR9                   1259
#define IDC_COMBO19                     1260
#define IDC_OBJECT10                    1260
#define IDC_COMBO20                     1261
#define IDC_BEHAVIOR10                  1261
#define IDC_BUTTON_NEW_EVENT            1265
#define IDC_EVENT_TREE                  1266
#define IDC_SUBSYSTEM1                  1267
#define IDC_SUBSYSTEM2                  1268
#define IDC_SUBSYSTEM3                  1269
#define IDC_SUBSYSTEM4                  1270
#define IDC_SUBSYSTEM5                  1271
#define IDC_SUBSYSTEM6                  1272
#define IDC_SUBSYSTEM7                  1273
#define IDC_SUBSYSTEM8                  1274
#define IDC_SUBSYSTEM9                  1275
#define IDC_SUBSYSTEM10                 1276
#define IDC_MESSAGE_LIST                1277
#define IDC_TREE                        1278
#define IDC_MESSAGE_TEXT                1279
#define IDC_NUM_TIMES                   1280
#define IDC_RATE                        1281
#define IDC_SPIN_RATE                   1282
#define IDC_SPIN_NUM_TIMES              1283
#define IDC_NEW                         1284
#define IDC_SLIDER1                     1285
#define IDC_TOTAL                       1287
#define IDC_INDEX                       1291
#define IDC_COUNT                       1293
#define IDC_SHIP_POOL                   1293
#define IDC_MIN_X                       1294
#define IDC_MAX_X                       1295
#define IDC_MIN_Y                       1296
#define IDC_MAX_Y                       1297
#define IDC_MIN_Z                       1298
#define IDC_MAX_Z                       1299
#define IDC_DENSITY                     1300
#define IDC_AVG_SPEED                   1301
#define IDC_DENSITY_SPIN                1302
#define IDC_LIST                        1304
#define IDC_USES                        1305
#define IDC_USES_SPIN                   1306
#define IDC_ADD                         1308
#define IDC_BROWSE                      1309
#define IDC_BEHAVIOR                    1312
#define IDC_ARRIVAL_DELAY               1313
#define IDC_DEPARTURE_DELAY             1315
#define IDC_ARRIVAL_DELAY_SPIN          1318
#define IDC_WING                        1321
#define IDC_NAME                        1322
#define IDC_REINFORCEMENT               1323
#define IDC_MAIN_HALL                   1323
#define IDC_DEBRIEFING_PERSONA          1324
#define IDC_DOCK1                       1327
#define IDC_INNER_MIN_X                 1327
#define IDC_DOCK2                       1328
#define IDC_INNER_MAX_X                 1328
#define IDC_DOCK3                       1329
#define IDC_INNER_MIN_Y                 1329
#define IDC_DOCK4                       1330
#define IDC_INNER_MAX_Y                 1330
#define IDC_DOCK5                       1331
#define IDC_INNER_MIN_Z                 1331
#define IDC_DOCK6                       1332
#define IDC_INNER_MAX_Z                 1332
#define IDC_DOCK7                       1333
#define IDC_DOCK8                       1334
#define IDC_DOCK9                       1335
#define IDC_DOCK10                      1336
#define IDC_WINGS_COUNT                 1338
#define IDC_WINGS_SHP_COUNT             1338
#define IDC_LIGHT_AMOUNT                1339
#define IDC_WINGS_WPN_COUNT             1339
#define IDC_LIST1                       1341
#define IDC_WING_LIST                   1341
#define IDC_WEAPON_LIST                 1341
#define IDC_SUN1_LIST                   1341
#define IDC_EDIT1                       1342
#define IDC_AMMO1                       1342
#define IDC_GOAL_NAME                   1342
#define IDC_HOTKEY                      1342
#define IDC_SBITMAP_LIST                1342
#define IDC_WEAPON_VARIABLES_LIST       1342
#define IDC_EDIT2                       1343
#define IDC_AMMO2                       1343
#define IDC_TEXT                        1343
#define IDC_INTERVAL_TIME               1343
#define IDC_GOAL_SCORE                  1343
#define IDC_ARRIVAL_DELAY_MIN           1343
#define IDC_EDIT_Z                      1343
#define IDC_SCORE                       1343
#define IDC_MAX_PLAYERS                 1343
#define IDC_BANK                        1343
#define IDC_ADD_VARIABLE_DEFAULT_VALUE  1343
#define IDC_SPECIAL_INNER_RAD           1343
#define IDC_SQUAD_LOGO                  1343
#define IDC_SQUADRON_WING_NAME_1        1343
#define IDC_SOUND_ENVIRONMENT_DAMPING   1343
#define IDC_EDIT3                       1344
#define IDC_AMMO3                       1344
#define IDC_TIME                        1344
#define IDC_DESTROY_VALUE               1344
#define IDC_ARRIVAL_DELAY_MAX           1344
#define IDC_EDIT_X                      1344
#define IDC_OBJ_KEY_TEXT                1344
#define IDC_PITCH                       1344
#define IDC_SPECIAL_OUTER_RAD           1344
#define IDC_LOADING_SCREEN1024          1344
#define IDC_ABBREV_CAMPAIGN             1344
#define IDC_TVT_WING_NAME_1             1344
#define IDC_ASSIST_SCORE                1344
#define IDC_SOUND_ENVIRONMENT_VOLUME    1344
#define IDC_EDIT4                       1345
#define IDC_AMMO4                       1345
#define IDC_VOICE                       1345
#define IDC_ARRIVAL_DISTANCE            1345
#define IDC_SUN1_B                      1345
#define IDC_ABBREV_COMMAND_BRIEFING     1345
#define IDC_STARTING_WING_NAME_2        1345
#define IDC_SUBSYS                      1346
#define IDC_SPECIAL_SHOCK_SPEED         1346
#define IDC_SBITMAP_B                   1346
#define IDC_WING_SQUAD_LOGO             1346
#define IDC_ABBREV_BRIEFING             1346
#define IDC_SQUADRON_WING_NAME_2        1346
#define IDC_VELOCITY                    1347
#define IDC_ABBREV_DEBRIEFING           1347
#define IDC_TVT_WING_NAME_2             1347
#define IDC_SPECIAL_DEATHROLL_TIME      1347
#define IDC_SKYBOX_B                    1347
#define IDC_SHIELDS                     1348
#define IDC_ABBREV_MISSION              1348
#define IDC_SQUADRON_WING_NAME_5        1348
#define IDC_DOCKED                      1349
#define IDC_EXAMPLE                     1349
#define IDC_SQUADRON_WING_NAME_3        1349
#define IDC_DOCKEE                      1349
#define IDC_DAMAGE                      1350
#define IDC_SQUADRON_WING_NAME_4        1350
#define IDC_DAMAGE_SPIN                 1351
#define IDC_STARTING_WING_NAME_3        1351
#define IDC_SHIELDS_SPIN                1352
#define IDC_VELOCITY_SPIN               1353
#define IDC_INITIAL_STATUS              1354
#define IDC_HULL_SPIN                   1355
#define IDC_HULL                        1356
#define IDC_AI_CLASS2                   1357
#define ID_OK                           1360
#define ID_CLOSE                        1361
#define ID_LOAD                         1362
#define IDC_ALIGN                       1364
#define IDC_SEXP_TREE                   1365
#define IDC_MOVE_UP                     1368
#define ID_CPGN_CLOSE                   1369
#define IDC_CARGO_KNOWN                 1370
#define IDC_SHIP_TBL                    1371
#define IDC_TOGGLE_SUBSYSTEM_SCANNING   1371
#define IDC_UPDATE_DEPARTURE            1372
#define IDC_NEXT                        1373
#define IDC_ADD_STAGE                   1374
#define IDC_NEXT_DEBRIEF                1375
#define IDC_MAKE_ICON                   1378
#define IDC_DELETE_ICON                 1379
#define IDC_STAGE_TITLE                 1380
#define IDC_ICON_LABEL                  1381
#define IDC_PREV                        1382
#define IDC_PREV_DEBRIEF                1383
#define IDC_INSERT_STAGE                1384
#define IDC_ICON_TEXT                   1385
#define IDC_INSERT                      1385
#define IDC_GOTO_VIEW                   1388
#define IDC_SAVE_VIEW                   1389
#define IDC_BROWSE_AVI                  1390
#define IDC_BROWSE_WAVE                 1391
#define IDC_BROWSE_WAVE2                1392
#define IDC_DEBRIEF_TITLE               1393
#define IDC_PROTECT_SHIP                1394
#define IDC_REPEAT_COUNT                1400
#define IDC_REMOVE_NO_MESSAGE           1401
#define IDC_TRIGGER_COUNT               1401
#define IDC_ADD_YES_MESSAGE             1402
#define IDC_REMOVE_YES_MESSAGE          1403
#define IDC_NO_MESSAGE_LIST             1404
#define IDC_ADD_NO_MESSAGE              1406
#define IDC_DELAY                       1407
#define IDC_DELAY_SPIN                  1408
#define IDC_HELP_BOX                    1409
#define IDC_HELP_BOX2                   1410
#define IDC_MINI_HELP_BOX               1410
#define IDC_asdf                        1412
#define IDC_DESTROY_SPIN                1413
#define IDC_IGNORE_ORDERS               1414
#define IDC_CHECK2                      1415
#define IDC_SPECIAL_EXP                 1415
#define IDC_SPECIAL_HITPOINTS           1416
#define IDC_EVENT_SCORE                 1419
#define IDC_PROPAGATE_ICONS             1420
#define IDC_LOCAL                       1421
#define IDC_MISSION_DESC                1422
#define IDC_HIDE_CUES                   1423
#define IDC_CUE_FRAME                   1424
#define IDC_ID                          1425
#define IDC_HAS_SHIELDS                 1426
#define IDC_XZ_PLANE                    1427
#define IDC_XY_PLANE                    1428
#define IDC_YZ_PLANE                    1429
#define IDC_SPIN_Y                      1430
#define IDC_SPIN_X                      1431
#define IDC_SPIN_Z                      1432
#define IDC_EDIT_Y                      1433
#define IDC_TYPE_YES                    1434
#define IDC_TYPE_NO                     1435
#define IDC_TEAM_YES                    1436
#define IDC_TEAM_NO                     1437
#define IDC_ESCORT                      1438
#define IDC_PLAYER_SHIP                 1440
#define IDC_CHAINED                     1441
#define IDC_CHAIN_DELAY                 1442
#define IDC_POOL_SPIN                   1443
#define IDC_POOL                        1444
#define IDC_WEAPON_POOL                 1444
#define IDC_OBJ_TEXT                    1445
#define IDC_REC_TEXT                    1446
#define IDC_NO_ARRIVAL_MUSIC            1447
#define IDC_CUT_NEXT                    1448
#define IDC_CUT_PREV                    1449
#define IDC_NO_ARRIVAL_WARP             1450
#define IDC_NO_DEPARTURE_WARP           1451
#define IDC_BRIEFING_CUTSCENE           1452
#define IDC_MIN_PLAYERS                 1453
#define IDC_EXACT_NUMBER                1454
#define IDC_EXACT_PLAYERS               1455
#define IDC_HEADING                     1456
#define IDC_NO_ARRIVAL_MESSAGE          1457
#define IDC_NO_MUSIC                    1459
#define ID_UPDATE                       1460
#define IDC_SHIP_LOCKED                 1461
#define IDC_WEAPONS_LOCKED              1462
#define IDC_INITIAL_LIST                1464
#define IDC_FULL_WAR                    1465
#define IDC_NEW_MSG                     1466
#define IDC_MESSAGE_NAME                1467
#define IDC_INVULNERABLE                1469
#define IDC_SINGLE                      1470
#define IDC_INVULNERABLE2               1470
#define IDC_TARGETABLE_AS_BOMB          1470
#define IDC_MULTI                       1471
#define IDC_HIDDEN_FROM_SENSORS         1471
#define IDC_TRAINING                    1472
#define IDC_LINES                       1472
#define IDC_PRIMITIVE_SENSORS           1472
#define IDC_NO_SUBSPACE_DRIVE           1473
#define IDC_ANI_FILENAME                1474
#define IDC_GUARDIAN                    1474
#define IDC_SCANNABLE                   1475
#define IDC_RED_ALERT                   1476
#define IDC_VAPORIZE                    1476
#define IDC_SCRAMBLE                    1477
#define IDC_FRIENDLY_STEALTH_INVISIBLE  1477
#define IDC_KDAMAGE                     1478
#define IDC_NO_BRIEFING                 1478
#define IDC_NO_DYNAMIC                  1479
#define IDC_NO_DEBRIEFING               1479
#define IDC_KAMIKAZE                    1480
#define IDC_NUM_PLAYERS                 1481
#define IDC_REDALERTCARRY               1481
#define IDC_PLAYERS_LABEL               1482
#define IDC_NO_BANK                     1482
#define IDC_BROWSE_ANI                  1483
#define IDC_AFFECTED_BY_GRAVITY         1483
#define IDC_RESPAWNS                    1484
#define IDC_NO_DEATH_SCREAM             1484
#define IDC_RESPAWN_SPIN                1485
#define IDC_STEALTH                     1485
#define IDC_ALWAYS_DEATH_SCREAM         1486
#define IDC_MAX_RESPAWN_DELAY           1486
#define IDC_NAV_CARRY                   1487
#define IDC_MAX_RESPAWN_DELAY_SPIN      1487
#define IDC_NAV_NEEDSLINK               1488
#define IDC_OBJ_TEAM                    1489
#define IDC_SCRAMBLE_MESSAGES           1489
#define IDC_CAMPAIGN_TYPE               1491
#define IDC_SUPPORT_ALLOWED             1492
#define IDC_SUBSPACE                    1493
#define IDC_UPDATE                      1494
#define IDC_DESC                        1495
#define IDC_MISSISON_LOOP_DESC          1495
#define IDC_NO_PROMOTION                1496
#define IDC_DESC2                       1496
#define ID_CANCEL                       1497
#define IDC_BUTTON3                     1498
#define IDC_PASTE_VIEW                  1498
#define IDC_DISABLE_BUILTIN_MSGS        1498
#define IDC_LOOP_BRIEF_SOUND_BROWSE     1498
#define IDC_SET_AS_PLAYER_SHIP          1498
#define IDC_IMPORT_BACKGROUND           1498
#define IDC_FULLNEB                     1499
#define IDC_NO_TRAITOR                  1499
#define IDC_ADD_VARIABLE_NAME           1500
#define IDC_SWAP_BACKGROUND             1500
#define IDC_MODIFY_DEFAULT_VALUE        1502
#define IDC_NEB_INTENSITY               1503
#define IDC_NEB2_INTENSITY              1503
#define IDC_ESCORT_PRIORITY             1504
#define IDC_ENABLE_INNER_BOX            1505
#define IDC_ENABLE_SPECIAL_EXP          1506
#define IDC_SPECIAL_DAMAGE              1507
#define IDC_ENABLE_SHOCKWAVE            1508
#define IDC_SPECIAL_BLAST               1509
#define IDC_CARGO_NAME                  1509
#define IDC_RESPAWN_PRIORITY            1510
#define IDC_ENABLE_DEATHROLL_TIME       1510
#define IDC_SQUAD_NAME                  1511
#define IDC_ASTEROID_DEBRIS_FIELD       1512
#define IDC_PASSIVE_SPECIES_TERRAN      1513
#define IDC_PASSIVE_SPECIES_VASUDAN     1514
#define IDC_PASSIVE_SPECIES_SHIVAN      1515
#define IDC_SUN1_H                      1516
#define IDC_SBITMAP_H                   1517
#define IDC_SUN1_SCALE                  1518
#define IDC_SBITMAP_SCALE               1519
#define IDC_SBITMAP_SCALE_X             1519
#define IDC_SUN1_P                      1520
#define IDC_SUN1_SCALE_SPIN             1521
#define IDC_SKYBOX_H                    1521
#define IDC_SUN1_P_SPIN                 1522
#define IDC_SUN1_B_SPIN                 1523
#define IDC_SUN1_H_SPIN                 1524
#define IDC_SBITMAP_P                   1525
#define IDC_SBITMAP_H_SPIN              1526
#define IDC_SBITMAP_B_SPIN              1527
#define IDC_BEAM_PROTECT_SHIP           1527
#define IDC_SBITMAP_P_SPIN              1528
#define IDC_FLAK_PROTECT_SHIP           1528
#define IDC_SBITMAP_SCALE_SPIN          1529
#define IDC_SBITMAP_SCALE_Y             1529
#define IDC_LASER_PROTECT_SHIP          1529
#define IDC_POOF0                       1530
#define IDC_MISSILE_PROTECT_SHIP        1530
#define IDC_POOF1                       1531
#define IDC_POOF2                       1532
#define IDC_POOF3                       1533
#define IDC_POOF4                       1534
#define IDC_POOF5                       1535
#define IDC_SBITMAP_DIV_X               1536
#define IDC_SBITMAP_DIV_Y               1537
#define IDC_STATS_TEXT                  1537
#define IDC_SUBTYPE1                    1538
#define IDC_SKYBOX_P                    1538
#define IDC_SUBTYPE2                    1539
#define IDC_SPECIAL_WARPIN              1539
#define IDC_SKYBOX_P_SPIN               1539
#define IDC_SUBTYPE3                    1540
#define IDC_LOOP_BRIEF_ANIM             1540
#define IDC_SKYBOX_B_SPIN               1540
#define IDC_LOOP_BRIEF_SOUND            1541
#define IDC_SBITMAP_H_SPIN2             1541
#define IDC_SKYBOX_H_SPIN               1541
#define IDC_SPECS_TOGGLE_TRAILS         1542
#define IDC_SUPPORT_REPAIR              1543
#define IDC_SUPPORT_REPAIRS_HULL        1543
#define IDC_WING_SQUAD_LOGO_BUTTON      1543
#define IDC_BEAM_FREE_ALL_BY_DEFAULT    1544
#define IDC_NEB_TOGGLE_TRAILS           1544
#define IDC_ST_OVERRIDE_NEB             1545
#define IDC_MAINHALL_LABEL              1545
#define IDC_3D_WARP_EFFECT              1545
#define IDC_ALLOW_DOCK_TREES            1545
#define IDC_MISSION_OPTIONS             1546
#define IDC_PLAYER_START_AI             1546
#define IDC_CUSTOM_TECH_DB              1547
#define IDC_USE_AUTOPILOT_CINEMATICS    1547
#define IDC_2D_MISSION                  1548
#define IDC_LABEL1                      1549
#define IDC_2D_MISSION2                 1549
#define IDC_ALWAYS_SHOW_GOALS           1549
#define IDC_LABEL2                      1550
#define IDC_ALWAYS_SHOW_GOALS2          1550
#define IDC_END_TO_MAINHALL             1550
#define IDC_NEW_TEXTURE                 1551
#define IDC_TEXTURES                    1552
#define IDC_OLD_TEXTURE_LIST            1553
#define IDC_RESTRICT_ARRIVAL            1553
#define IDC_ENABLE_SPECIAL_HITPOINTS    1554
#define IDC_RESTRICT_DEPARTURE          1554
#define IDC_SPECIAL_SHIELDS             1555
#define IDC_SPECIAL_HULL                1556
#define IDC_LOADING_SCREEN_BUTTON1024   1557
#define IDC_ENABLE_SPECIAL_SHIELD       1557
#define IDC_LOADING_SCREEN640           1558
#define IDC_TYPE_CAMPAIGN_PERSISTENT    1559
#define IDC_MAX_HULL_REPAIR_VAL         1559
#define IDC_TYPE_PLAYER_PERSISTENT      1560
#define IDC_SKYBOX_FNAME                1560
#define IDC_HULL_REPAIR_CEILING2        1560
#define IDC_MAX_SUBSYS_REPAIR_VAL       1560
#define IDC_PASSIVE_SPECIES_ANCIENT     1561
#define IDC_AMBIENT_R_SLIDER            1561
#define IDC_CONTRAIL_THRESHOLD          1561
#define IDC_TYPE_NETWORK_VARIABLE       1561
#define IDC_PASSIVE_SPECIES_USER1       1562
#define IDC_AMBIENT_G_SLIDER            1562
#define IDC_PASSIVE_SPECIES_USER2       1563
#define IDC_AMBIENT_B_SLIDER            1563
#define IDC_PASSIVE_SPECIES_USER3       1564
#define IDC_AMBIENT_R_TEXT              1564
#define IDC_PASSIVE_SPECIES_USER4       1565
#define IDC_AMBIENT_G_TEXT              1565
#define IDC_AMBIENT_B_TEXT              1566
#define IDC_CONTRAIL_THRESHOLD_CHECK    1567
#define IDC_FILENAME_OPTIONS            1568
#define IDC_FILE_NAME_OPTIONS           1568
#define IDC_SCRIPT_OPTIONS              1569
#define IDC_SEPARATORS                  1570
#define IDC_ENTRY                       1570
#define IDC_LBL_ABBREV_CAMPAIGN         1571
#define IDC_ABBREVIATIONS               1572
#define IDC_CUSTOM_WING_NAMES           1572
#define IDC_LBL_ABBREV_COMMAND_BRIEFING 1573
#define IDC_STARTING_WING_NAMES_LABEL   1573
#define IDC_LBL_ABBREV_BRIEFING         1574
#define IDC_SQUADRON_WING_NAMES_LABEL   1574
#define IDC_LBL_ABBREV_DEBRIEFING       1575
#define IDC_TVT_WING_NAMES_LABEL        1575
#define IDC_LBL_ABBREV_MESSAGE          1576
#define IDC_STARTING_WING_NAME_1        1576
#define IDC_LBL_EXAMPLE                 1577
#define IDC_LBL_ABBREV_MISSION          1578
#define IDC_FLIP_ICON                   1578
#define IDC_DISABLE_BUILTIN_SHIP        1579
#define IDC_OTHER                       1579
#define IDC_USE_WING_ICON               1579
#define IDC_DISABLE_BUILTIN_COMMAND_MSGS 1580
#define IDC_LBL_OTHER_SUFFIX            1580
#define IDC_USE_CARGO_ICON              1580
#define IDC_PRIMARIES_LOCKED            1581
#define IDC_EXPORT                      1581
#define IDC_SECONDARIES_LOCKED          1582
#define IDC_SUBSTITUTE_BRIEFING_MUSIC   1582
#define IDC_RESTRICT_PATHS_LABEL        1584
#define IDC_PATH_LIST                   1585
#define IDC_BACKGROUND                  1586
#define IDC_ENVMAP                      1589
#define IDC_ENVMAP_BROWSE               1590
#define IDC_ENTRY_FORMAT                1590
#define IDC_NO_REPLACE                  1591
#define IDC_SKYBOX_MODEL                1592
#define IDC_ALT_AS_CALLSIGN             1593
#define IDC_DEACTIVATE_AUTOPILOT        1594
#define IDC_HIDE_SHIP_NAME              1594
#define IDC_SET_CLASS_DYNAMICALLY       1595
#define IDC_ALT_SHIP_CLASS              1598
#define ID_STATIC                       1600
#define IDC_DEFAULT_TO_CLASS            1601
#define IDC_ALT_CLASS_UP                1602
#define IDC_ALT_CLASS_DOWN              1603
#define IDC_ALT_CLASS_INSERT            1604
#define IDC_SKY_FLAG_NO_LIGHTING        1609
#define IDC_SKY_FLAG                    1610
#define IDC_SKY_FLAG_XPARENT            1610
#define IDC_SKY_FLAG_NO_ZBUFF           1611
#define IDC_SKY_FLAG_NO_CULL            1612
#define IDC_SKY_FLAG_NO_GLOW            1613
#define IDC_SKY_FLAG_CLAMP              1614
#define IDC_TURRETS_LOCKED              1615
#define IDC_AFTERBURNER_LOCKED          1616
#define IDC_FORCE_SHIELDS               1617
#define IDC_STORY_FILE                  1618
#define IDC_FONT_FILE                   1619
#define IDC_FICTION_MUSIC               1620
#define IDC_SOUND_ENVIRONMENT_LABEL     1621
#define IDC_FONT_FILE2                  1621
#define IDC_VOICE_FILE                  1621
#define IDC_SOUND_ENVIRONMENT_VOLUME_LABEL 1622
#define IDC_SOUND_ENVIRONENT_DAMPING_LABEL 1623
#define IDC_SOUND_ENVIRONMENT_DECAY_LABEL 1624
#define IDC_SOUND_ENVIRONMENT_DECAY     1625
#define IDC_SOUND_ENVIRONMENT_BUTTON    1626
#define IDC_SOUND_ENVIRONMENT_TEST      1627
#define IDC_GROUP_MESSAGES              1628
#define IDC_INCLUDE_SENDER              1629
#define IDC_DISABLE_ETS                 1630
#define IDC_IMMOBILE                    1631
#define IDC_DISABLE_ETS2                1632
#define IDC_CLOAKED                     1632
#define IDC_NEB_NEAR_MULTIPLIER         1632
#define IDC_EDIT6                       1633
#define IDC_NEB_FAR_MULTIPLIER          1634
#define IDC_MISSION_LOG_TRUE            1635
#define IDC_MISSION_LOG_FALSE           1636
#define IDC_MISSION_LOG_STATE_CHANGE    1637
#define IDC_MISSION_LOG_ALWAYS_FALSE    1638
#define IDC_MISSION_LOG_1ST_REPEAT      1639
#define IDC_MISSION_LOG_LAST_REPEAT     1640
#define IDC_MISSION_LOG_1ST_TRIGGER     1641
#define IDC_MISSION_LOG_LAST_TRIGGER    1642
#define IDC_NO_COLLIDE                  1643
#define ID_FILE_MISSIONNOTES            32771
#define ID_DUPLICATE                    32774
#define ID_VIEW_ROTATE                  32775
#define ID_SELECT                       32776
#define ID_ROTATE                       32777
#define ID_VIEW_ZOOM                    32778
#define ID_DELETE                       32779
#define ID_MOVE                         32780
#define ID_VIEW_PAN                     32781
#define ID_VIEW_FIGHTERS                32784
#define ID_VIEW_CAPITALSHIPS            32785
#define ID_VIEW_PLANETS                 32786
#define ID_VIEW_MISCOBJECTS             32787
#define ID_FILE_PREFERENCES             32788
#define ID_EDIT_DELETE                  32789
#define ID_EDIT_HOLD                    32790
#define ID_EDIT_FETCH                   32791
#define ID_CONFIRM_DELETING             32791
#define ID_EDITORS_OBJECTS              32792
#define ID_EDITORS_AI_CLASSES           32793
#define ID_EDITORS_ART                  32794
#define ID_EDITORS_MESSAGE              32795
#define ID_EDITORS_MUSIC                32796
#define ID_EDITORS_SHIP_CLASSES         32798
#define ID_EDITORS_SHIPS                32799
#define ID_EDITORS_GOALS                32800
#define ID_EDITORS_WAYPOINTS            32801
#define ID_EDITORS_SOUND                32802
#define ID_EDITORS_TERRAIN              32803
#define ID_EDIT_DUPLICATE               32804
#define ID_VIEW_ELEVATIONS              32806
#define ID_VIEW_WAYPOINTS               32807
#define ID_VIEW_GRID                    32808
#define ID_MIKE_GRIDCONTROL             32811
#define ID_PROPERTIES_ONE               32812
#define ID_PROPERTIES_TWO               32813
#define ID_PROPERTIES_THREE             32814
#define ID_PROPERTIES_FOUR              32815
#define ID_PROPERTIES_SUBMENU_SUB1      32816
#define ID_PROPERTIES_SUBMENU_SUB2      32817
#define ID_SHIP_TYPE_2                  32817
#define ID_MISCSTUFF_SHOWSHIPSASICONS   32818
#define IDR_MENU_POPUP_TOGGLE1          32819
#define ID_EDIT_POPUP_SHOW_SHIP_MODELS  32820
#define IDR_SHIP_POPUP_CHECK1           32822
#define ID_EDIT_POPUP_SHOW_SHIP_ICONS   32823
#define ID_SHIP_TYPE_3                  32824
#define ID_SHIP_TYPE_4                  32825
#define ID_SHIP_TYPE_5                  32826
#define ID_SHIP_TYPE_1                  32828
#define ID_SHIP_TYPE_0                  32829
#define ID_EDIT_SHIP_TYPE_6             32830
#define ID_MISC_STATISTICS              32831
#define ID_EDIT_POPUP_SHOW_COMPASS      32832
#define ID_CHANGE_VIEWPOINT_EXTERNAL    32835
#define ID_CHANGE_VIEWPOINT_START       32836
#define ID_CHANGE_VIEWPOINT_FOLLOW      32837
#define ID_ADD                          32839
#define ID_ADD_PLUS                     32840
#define ID_ADD_MINUS                    32841
#define ID_ADD_DESTROY                  32846
#define ID_ADD_DESTROY_WING             32847
#define ID_ADD_DISABLE                  32848
#define ID_ADD_MISSION_TIME             32849
#define ID_ADD_EQUALS                   32850
#define ID_ADD_GREATER_THAN             32851
#define ID_ADD_AND                      32852
#define ID_ADD_OR                       32853
#define ID_ADD_MULTIPLY                 32854
#define ID_ADD_DIVIDE                   32855
#define ID_ADD_MOD                      32856
#define ID_EDIT_TEXT                    32857
#define ID_ADD_TRUE                     32858
#define ID_ADD_FALSE                    32859
#define ID_HELP_INPUT_INTERFACE         32860
#define ID_ADD_LESS_THAN                32861
#define ID_ADD_ELAPSED_TIME             32862
#define ID_ADD_TIME_SHIP_DESTROYED      32863
#define ID_ADD_TIME_SHIP_ARRIVED        32864
#define ID_ADD_TIME_SHIP_DEPARTED       32865
#define ID_INFO                         32866
#define ID_REPLACE_DESTROY              32870
#define ID_REPLACE_DESTROY_WING         32871
#define ID_REPLACE_DISABLE              32872
#define ID_REPLACE_ELAPSED_TIME         32873
#define ID_REPLACE_TIME_SHIP_DESTROYED  32874
#define ID_REPLACE_TIME_SHIP_ARRIVED    32875
#define ID_REPLACE_TIME_SHIP_DEPARTED   32876
#define ID_REPLACE_TRUE                 32877
#define ID_REPLACE_FALSE                32878
#define ID_REPLACE_AND                  32879
#define ID_REPLACE_OR                   32880
#define ID_REPLACE_EQUALS               32881
#define ID_REPLACE_GREATER_THAN         32882
#define ID_REPLACE_LESS_THAN            32883
#define ID_REPLACE_PLUS                 32884
#define ID_REPLACE_MINUS                32885
#define ID_REPLACE_MULTIPLY             32886
#define ID_REPLACE_DIVIDE               32887
#define ID_REPLACE_MOD                  32888
#define ID_ADD_NUMBER                   32889
#define ID_ADD_STRING                   32890
#define ID_REPLACE_NUMBER               32891
#define ID_REPLACE_STRING               32892
#define ID_PLACEHOLDER                  32894
#define ID_SPEED1                       32898
#define ID_SPEED2                       32899
#define ID_SPEED5                       32900
#define ID_SPEED10                      32901
#define ID_SPEED3                       32902
#define ID_ROT1                         32903
#define ID_ROT2                         32904
#define ID_ROT3                         32905
#define ID_ROT4                         32906
#define ID_ROT5                         32907
#define ID_SPEED8                       32908
#define ID_EDIT_MODE_SHIPS              32909
#define ID_EDIT_MODE_WAYPOINTS          32910
#define ID_CONTROL_MODE_CAMERA          32911
#define ID_CONTROL_MODE_START           32912
#define ID_CONTROL_MODE_SHIP            32913
#define ID_SHOW_GRID_POSITIONS          32914
#define ID_SHOW_COORDINATES             32915
#define ID_SPEED50                      32917
#define ID_SPEED100                     32918
#define ID_SELECT_LIST                  32919
#define ID_CONTRAIN_X                   32920
#define ID_CONSTRAIN_Y                  32921
#define ID_BUTTON32922                  32922
#define ID_BUTTON32923                  32923
#define ID_ZOOM                         32924
#define ID_SELECTION_LOCK               32925
#define ID_BUTTON32926                  32926
#define ID_DISSOLVE_WING                32927
#define ID_SELECT_AND_MOVE              32932
#define ID_SELECT_AND_ROTATE            32933
#define ID_CONSTRAIN_X                  32934
#define ID_CONSTRAIN_Z                  32935
#define ID_CONSTRAIN_XZ                 32936
#define ID_FORM_WING                    32937
#define ID_REMOVE_WING                  32938
#define ID_DISBAND_WING                 32938
#define ID_DOUBLE_FINE_GRIDLINES        32939
#define ID_SHOW_DISTANCED               32940
#define ID_SHOW_DISTANCES               32941
#define ID_UNIVERSAL_HEADING            32942
#define ID_FIND_DISTANCE                32943
#define ID_BUTTON32944                  32944
#define ID_BUTTON32945                  32945
#define ID_CONSTRAIN_YZ                 32946
#define ID_CONSTRAIN_XY                 32947
#define ID_FLYING_CONTROLS              32948
#define ID_SELECT_AND_ROTATE_LOCALLY    32949
#define ID_ROTATE_LOCALLY               32950
#define ID_ZOOM_TO_SELECTED             32951
#define ID_ZOOM_SELECTED                32952
#define ID_ZOOM_EXTENTS                 32953
#define ID_SHOW_HORIZON                 32954
#define ID_EDITORS_WING                 32955
#define ID_SELECTSHIP_PLACEHOLDER       32959
#define ID_ADD_ESCORT                   32961
#define ID_ADD_DOCK                     32962
#define ID_ADD_TIME_WING_DESTROYED      32963
#define ID_ADD_TIME_WING_ARRIVED        32964
#define ID_ADD_TIME_WING_DEPARTED       32965
#define ID_REPLACE_ESCORT               32966
#define ID_REPLACE_DOCK                 32967
#define ID_REPLACE_TIME_WING_DESTROYED  32968
#define ID_REPLACE_TIME_WING_ARRIVED    32969
#define ID_REPLACE_TIME_WING_DEPARTED   32970
#define ID_SPLIT_LINE                   32971
#define ID_EDITORS_PLAYER               32972
#define ID_EDITORS_ORIENT               32973
#define ID_EDITORS_EVENTS               32974
#define ID_EDITORS_STARFIELD            32975
#define ID_EDITORS_BG_BITMAPS           32976
#define ID_EDITORS_REINFORCEMENT        32977
#define ID_ERROR_CHECKER                32978
#define ID_EDITORS_WAYPOINT             32979
#define ID_VIEW_OUTLINES                32980
#define ID_NEW_SHIP_TYPE                32981
#define ID_SHOW_STARFIELD               32983
#define ID_ASTEROID_EDITOR              32984
#define ID_RUN_FREESPACE                32985
#define ID_EDITOR_CAMPAIGN              32986
#define ID_SHOW_IFF_9                   32988
#define ID_SHOW_HOSTILE                 32989
#define ID_SHOW_SHIPS                   32990
#define ID_SHOW_STARTS                  32991
#define ID_TOGGLE_VIEWPOINT             32992
#define ID_CPGN_FILE_NEW                32995
#define ID_CPGN_FILE_OPEN               32996
#define ID_CPGN_FILE_SAVE               32997
#define ID_CPGN_FILE_SAVE_AS            32998
#define ID_SHOW_STARFRIELD              32999
#define ID_REVERT                       33000
#define ID_HIDE_OBJECTS                 33002
#define ID_SHOW_HIDDEN_OBJECTS          33003
#define ID_GROUP_SET                    33004
#define ID_EXPAND_ALL                   33005
#define ID_EDITORS_BRIEFING             33006
#define ID_EDITORS_DEBRIEFING           33007
#define ID_SAVE_CAMERA                  33008
#define ID_RESTORE_CAMERA               33009
#define ID_SHOW_SEXP_HELP               33010
#define ID_LOOKAT_OBJ                   33011
#define ID_GROUP1                       33012
#define ID_GROUP2                       33013
#define ID_GROUP3                       33014
#define ID_GROUP4                       33015
#define ID_GROUP5                       33016
#define ID_GROUP6                       33017
#define ID_GROUP7                       33018
#define ID_GROUP8                       33019
#define ID_GROUP9                       33020
#define ID_SET_GROUP1                   33021
#define ID_SET_GROUP2                   33022
#define ID_SET_GROUP3                   33023
#define ID_SET_GROUP4                   33024
#define ID_SET_GROUP5                   33025
#define ID_SET_GROUP6                   33026
#define ID_SET_GROUP7                   33027
#define ID_SET_GROUP8                   33028
#define ID_SET_GROUP9                   33029
#define ID_END_EDIT                     33031
#define ID_EDITORS_ADJUST_GRID          33032
#define ID_EDITORS_SHIELD_SYS           33033
#define ID_LEVEL_CAMERA                 33034
#define ID_EDIT_DELETE_WING             33035
#define ID_ALIGN_OBJ                    33036
#define ID_LEVEL_OBJ                    33037
#define ID_MARK_WING                    33038
#define ID_NEXT_OBJ                     33039
#define ID_PREV_OBJ                     33040
#define ID_CONTROL_OBJ                  33041
#define ID_DELETE_ROW                   33042
#define ID_REMOVE_MISSION               33043
#define ID_INSERT_ROW                   33044
#define ID_CHECKOUT                     33045
#define ID_CHECKIN                      33046
#define ID_ADD_REPEAT                   33047
#define ID_AA_GRIDLINES                 33048
#define ID_INITIAL_SHIPS                33049
#define ID_INITIAL_WEAPONS              33050
#define ID_TEAM_1                       33051
#define ID_TEAM_2                       33052
#define ID_TEAM_3                       33053
#define ID_EDITORS_CMD_BRIEF            33054
#define ID_DISABLE_UNDO                 33055
#define ID_END_OF_CAMPAIGN              33056
#define ID_SEXP_TREE_ADD_VARIABLE       33057
#define ID_SEXP_TREE_MODIFY_VARIABLE    33058
#define ID_NEXT_SUBSYS                  33059
#define ID_PREV_SUBSYS                  33060
#define ID_CANCEL_SUBSYS                33061
#define ID_SHOW_DOCK_POINTS             33065
#define ID_SHOW_PATHS                   33066
#define ID_DUMP_STATS                   33067
#define ID_FORMAT_FS2_OPEN              33069
#define ID_FORMAT_FS2_RETAIL            33070
#define ID_FORMAT_FS1                   33071
#define ID_FORMAT_FS1_RETAIL            33072
#define ID_EDITORS_SET_GLOBAL_SHIP_FLAGS 33073
#define ID_FILE_IMPORT_FSM              33074
#define ID_VIEW_LIGHTING                33079
#define ID_EDITORS_VOICE                33080
#define ID_SHOW_IFF_0                   33081
#define ID_SHOW_IFF_1                   33082
#define ID_SHOW_IFF_2                   33083
#define ID_SHOW_IFF_3                   33084
#define ID_SHOW_IFF_4                   33085
#define ID_SHOW_IFF_5                   33086
#define ID_SHOW_IFF_6                   33087
#define ID_SHOW_IFF_7                   33088
#define ID_SHOW_IFF_8                   33089
#define ID_VIEW_FULL_DETAIL             33090
#define ID_SAVEFORMAT_FS2OPEN           33091
#define ID_FORMAT_FS2_OPEN_COMP         33092
#define ID_AUTOBALANCE                  33093
#define ID_EDITORS_FICTION              33094
#define ID_INDICATOR_MODE               59142
#define ID_INDICATOR_LEFT               59143
#define ID_INDICATOR_RIGHT              59144
#define ID_INDICATOR_MODIFIED           59145

// Next default values for new objects
// 
#ifdef APSTUDIO_INVOKED
#ifndef APSTUDIO_READONLY_SYMBOLS
#define _APS_3D_CONTROLS                     1
#define _APS_NEXT_RESOURCE_VALUE        320
#define _APS_NEXT_COMMAND_VALUE         33098
#define _APS_NEXT_CONTROL_VALUE         1644
#define _APS_NEXT_SYMED_VALUE           105
#endif
#endif
